/****************************************************/
/* Guns and crime                                   */
/* Long run: no lags, semilog                       */
/* Guns are GSSHG, PHG                              */
/* All crime categories                             */
/* Produces Table 4                                 */
/****************************************************/

/* insert library reference here */
libname a "/home/cemood/myfiles/Data";
options nocenter nolabel;

/* get data from guns.sas7bdat */
data temp;set a.guns;

/* drop DC */
if state ne 9;


/* fix prison population here             */
/* note that prison is stock at year end  */
if pradj=. then pradj=0;
prison=prcye+pradj;
prison=(prison+lag(prison))/2;
prison=prison/pop;

/* make variables here */

ptot=p0099;
p1517=p1517/ptot;
p1824=p1824/ptot;
p2534=p2534/ptot;
p3544=p3544/ptot;
p4554=p4554/ptot;
p5564=p5564/ptot;
employ=employ/1000000;
rpcpi=rpcpi/1000;
rpcui=rpcui/1000;
rpcim=rpcim/1000;
rpcrpo=rpcrpo/1000;

trend=year-76;



/***********************/
/* define arrests here */
/***********************/
crmaj=crmur+crrap+crrob+crass+crbur;
aoass=aoaga;
aomaj=aomur*(crmur/crmaj)+aorap*(crrap/crmaj)
       +aorob*(crrob/crmaj)+aoass*(crass/crmaj)
       +aobur*(crbur/crmaj);


crmur=crmur/pop*1000;
crrap=crrap/pop*1000;
crrob=crrob/pop*1000;
crass=crass/pop*1000;
crbur=crbur/pop*1000;
crlar=crlar/pop*1000;
crmv=crmv/pop*1000;
crmaj=crmaj/pop*1000;


military=empmil;

/* define guns here */

gss=gssra*100;
gsshg=gsshgra*100;


array yr yr77-yr98;
do over yr;
if year-76=_i_ then yr=1;else yr=0;
end;

array st st1-st51;
do over st;
if state=_i_ then st=1;else st=0;
end;

pgs=pctgsuic;

data temp;set temp;

/* take logs here */
Array x crmaj crmur crrap crrob crass crbur;
        do over x;
        x=log(x);
        end;

/* Major Crime */

proc reg;
Title "OLS: long run static models";
Title2 "Crmaj w/ arrests";
weight pop;
model crmaj=gsshg prison aomaj 
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
Title "OLS: long run static models";
Title2 "Crmaj w/ arrests";
weight pop;
model crmaj=phg prison aomaj
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crmaj w/o arrests";
weight pop;

model crmaj=gsshg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crmaj w/o arrests";
weight pop;
model crmaj=phg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;

/* Murder */

proc reg;
Title "OLS: long run static models";
Title2 "Crmur w/ arrests";
weight pop;
model crmur=gsshg prison aomur 
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
Title "OLS: long run static models";
Title2 "Crmur w/ arrests";
weight pop;
model crmur=phg prison aomur
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crmur w/o arrests";
weight pop;

model crmur=gsshg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crmur w/o arrests";
weight pop;
model crmur=phg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;


/* Rape */

proc reg;
Title "OLS: long run static models";
Title2 "Crrap w/ arrests";
weight pop;
model crrap=gsshg prison aorap
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
Title "OLS: long run static models";
Title2 "Crrap w/ arrests";
weight pop;
model crrap=phg prison aorap 
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crrap w/o arrests";
weight pop;

model crrap=gsshg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crrap w/o arrests";
weight pop;
model crrap=phg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;

/* Robbery */

proc reg;
Title "OLS: long run static models";
Title2 "Crrob w/ arrests";
weight pop;
model crrob=gsshg prison aorob 
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
Title "OLS: long run static models";
Title2 "Crrob w/ arrests";
weight pop;
model crrob=phg prison aorob
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crrob w/o arrests";
weight pop;

model crrob=gsshg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crrob w/o arrests";
weight pop;
model crrob=phg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;

/* Assault */

proc reg;
Title "OLS: long run static models";
Title2 "Crass w/ arrests";
weight pop;
model crass=gsshg prison aoass 
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
Title "OLS: long run static models";
Title2 "Crass w/ arrests";
weight pop;
model crass=phg prison aoass
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crass w/o arrests";
weight pop;

model crass=gsshg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crass w/o arrests";
weight pop;
model crass=phg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;

/* Burglary */

proc reg;
Title "OLS: long run static models";
Title2 "Crbur w/ arrests";
weight pop;
model crbur=gsshg prison aobur 
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
Title "OLS: long run static models";
Title2 "Crbur w/ arrests";
weight pop;
model crbur=phg prison aobur
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crbur w/o arrests";
weight pop;

model crbur=gsshg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;
proc reg;
title2 "Crbur w/o arrests";
weight pop;
model crbur=phg prison  
         metpct ampct employ unrate
        p1517 p1824 p2534 p3544 p4554 p5564
        rpcpi rpcim rpcui rpcrpo
        st2-st8 st10-st51 yr83-yr98 ;




Run;
