/****************************************************/
/* Guns and Crime                                   */
/* Granger causality tests                          */
/* Does crime cause guns?                           */
/* Short run, first differences, not logged         */
/* All crime categories                             */
/* Produces Table 6                                 */
/****************************************************/

/*  insert library reference here */
libname a "/home/cemood/myfiles/Data";
options nocenter nolabel pagesize=1000;

/* get data from guns.sas7bdat */
data temp;set a.guns;

/* drop DC */
if state ne 9;

/* Define pgs here */
Pgs=pctgsuic;

/* Define guns here */
gsshg=gsshgra*100;
gss=gssra*100;


/* fix prison population here             */
/* note that prison is stock at year end  */
if pradj=. then pradj=0;
prison=prcye+pradj;
prison=(prison+lag(prison))/2;
prison=prison/pop;

/* make variables here */

ptot=p0099;
p1517=p1517/ptot;
p1824=p1824/ptot;
p2534=p2534/ptot;
p3544=p3544/ptot;
p4554=p4554/ptot;
p5564=p5564/ptot;

rpcpi=rpcpi/1000;
rpcui=rpcui/1000;
rpcim=rpcim/1000;
rpcrpo=rpcrpo/1000;
employ=employ/1000000;

trend=year-76;

crmaj=crmur+crrap+crrob+crass+crbur;
crvio=crmur+crrap+crrob+crass;
crmur=crmur/pop*1000;
crrap=crrap/pop*1000;
crrob=crrob/pop*1000;
crass=crass/pop*1000;
crbur=crbur/pop*1000;
crlar=crlar/pop*1000;
crmv=crmv/pop*1000;
crmaj=crmaj/pop*1000;
crvio=crvio/pop*1000;

military=empmil;

/*******************************/
/* Define arrests here         */
/*******************************/
aoass=aoaga;
aomaj=aomur*(crmur/crmaj)+aorap*(crrap/crmaj)
       +aorob*(crrob/crmaj)+aoass*(crass/crmaj)
       +aobur*(crbur/crmaj);


array yr yr77-yr98;
do over yr;
if year-76=_i_ then yr=1;else yr=0;
end;

array st st1-st51;
do over st;
if state=_i_ then st=1;else st=0;
end;


/* Take per capita gun mags here */

Array zz gunsamm amhgs amhms amrmms;
do over zz;
zz=zz/pop;
end;

/* dont take logs */
	
/* take first differences here */

Array xx  crmaj crmur crrap crrob crass crbur
		aomaj aomur aorap aorob aoass aobur 
		gss gsshg phg pgun pgs prison 
		gunsamm amhgs amhms amrmms
    		metpct ampct military employ unrate
		p1517 p1824 p2534 p3544 p4554 p5564
		rpcpi rpcim rpcui rpcrpo;
	do over xx;
	xx=dif(xx);
end;

dpop=dif(pop);

/* take lags here  */

Array z crmaj crmur crrap crrob crass crbur
		aomaj aomur aorap aorob aoass aobur  
	gss gsshg phg pgun pgs 
	prison 
	gunsamm amhgs amhms amrmms
    	metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	;
Array z1 crmaj1 crmur1 crrap1 crrob1 crass1 crbur1
		 aomaj1 aomur1 aorap1 aorob1 aoass1 aobur1 
	gss1 gsshg1 phg1 pgun1 pgs1
	pr1  
	ga1 amhg1 amh1 amrm1
    	metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	;
Array z2 crmaj2 crmur2 crrap2 crrob2 crass2 crbur2
		aomaj2 aomur2 aorap2 aorob2 aoass2 aobur2 
		gss2 gsshg2 phg2 pgun2 pgs2 
		pr2 
	ga2 amhg2 amh2 amrm2
    	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	;
	

do over z;
z1=lag(z);
z2=lag2(z);


end;

pr=prison;

/* Granger Tests */
/* Major Crime GSSHG */

proc reg;
Title "Granger, major crime, GSSHG, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model gsshg = crmaj1-crmaj2 gsshg1-gsshg2 pr	aomaj
metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	yr82-yr96
 ;
crime:test crmaj1+crmaj2;
controls:test pr,aomaj,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;



	/* Granger Tests, Major Crime, Phg */

proc reg;
Title "Granger, major crime, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model phg = crmaj1-crmaj2 phg1-phg2 pr
aomaj metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crmaj1+crmaj2;
controls:test pr,aomaj,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;

/* Murder GSSHG */

proc reg;
Title "Granger, Murder, GSSHG, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model gsshg = crmur1-crmur2 gsshg1-gsshg2 pr
	aomur
metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
;
crime:test crmur1+crmur2;
controls:test pr,aomur,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;



	/* Granger Tests, Murder, Phg */

proc reg;
Title "Granger, Murder, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model phg = crmur1-crmur2 phg1-phg2 pr
aomur metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crmur1+crmur2;
controls:test pr,aomur,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;

/* Rape GSSHG */

proc reg;
Title "Granger, Rape, GSSHG, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model gsshg = crrap1-crrap2 gsshg1-gsshg2 pr
	aorap
metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
	
 ;
crime:test crrap1+crrap2;
controls:test pr,aorap,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;


	/* Granger Tests, Rape, Phg */

proc reg;
Title "Granger, Rape, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model phg = crrap1-crrap2 phg1-phg2 pr
aorap metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime: test crrap1+crrap2;
controls:test pr,aorap,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;

/* Robbery GSSHG */

proc reg;
Title "Granger, Robbery, GSSHG, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model gsshg = crrob1-crrob2 gsshg1-gsshg2 pr
	aorob
metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
	
 ;
crime:test crrob1+crrob2;
controls:test pr,aorob,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;


	/* Granger Tests, Robbery, Phg */

proc reg;
Title "Granger, Robbery, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model phg = crrob1-crrob2 phg1-phg2 pr
aorob metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crrob1+crrob2;
controls:test pr,aorob,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;

/* Assault GSSHG */

proc reg;
Title "Granger, Assault, GSSHG, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model gsshg = crass1-crass2 gsshg1-gsshg2 pr
	aoass
metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
	
 ;
crime:test crass1+crass2;
controls:test pr,aoass,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;

	/* Granger Tests, Assault, Phg */

proc reg;
Title "Granger, Assault, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model phg = crass1-crass2 phg1-phg2 pr
aoass  metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crass1+crass2;
controls:test pr,aoass,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;

/* Burglary GSSHG */

proc reg;
Title "Granger, Burglary, GSSHG, weighted, with arrests, year dummies ";
Title2 "No state dummies";
weight pop;

model gsshg = crbur1-crbur2 gsshg1-gsshg2 pr
	aobur
metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
	
 ;
crime:test crbur1+crbur2;
controls:test pr,aobur,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;


	/* Granger Tests, Burglary, Phg */

proc reg;
Title "Granger, Burglary, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No state dummies"
weight pop;

model phg = crbur1-crbur2 phg1-phg2 pr
aobur  metpct ampct  employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crbur1+crbur2;
controls:test pr,aobur,metpct,ampct, employ,unrate,
	p1517,p1824,p2534,p3544,p4554,p5564,
	rpcpi,rpcim,rpcui,rpcrpo ;


********************************************************************;
***** Dropping Control Variables                              ******;
********************************************************************;


/* Granger Tests */
/* Major Crime GSSHG */

proc reg;
Title "Granger, major crime, GSSHG, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model gsshg = crmaj1-crmaj2 gsshg1-gsshg2 yr82-yr96 	
 ;
crime:test crmaj1+crmaj2;




	/* Granger Tests, Major Crime, Phg */

proc reg;
Title "Granger, major crime, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model phg = crmaj1-crmaj2 phg1-phg2 yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crmaj1+crmaj2;

/* Murder GSSHG */

proc reg;
Title "Granger, Murder, GSSHG, weighted, with arrests, year dummies ult";
Title2 "No control variables";
weight pop;

model gsshg = crmur1-crmur2 gsshg1-gsshg2 yr82-yr96
;
crime:test crmur1+crmur2;



	/* Granger Tests, Murder, Phg */

proc reg;
Title "Granger, Murder, Phg, no st dum, weighted, with arrests, year dummies ult";
Title2 "No control variables";
weight pop;

model phg = crmur1-crmur2 phg1-phg2 yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crmur1+crmur2;


/* Rape GSSHG */

proc reg;
Title "Granger, Rape, GSSHG, weighted, with arrests, year dummies ult";
Title2 "No control variables";
weight pop;

model gsshg = crrap1-crrap2 gsshg1-gsshg2 yr82-yr96
	
 ;
crime:test crrap1+crrap2;



	/* Granger Tests, Rape, Phg */

proc reg;
Title "Granger, Rape, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model phg = crrap1-crrap2 phg1-phg2 yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime: test crrap1+crrap2;


/* Robbery GSSHG */

proc reg;
Title "Granger, Robbery, GSSHG, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model gsshg = crrob1-crrob2 gsshg1-gsshg2 yr82-yr96
 ;
crime:test crrob1+crrob2;



	/* Granger Tests, Robbery, Phg */

proc reg;
Title "Granger, Robbery, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model phg = crrob1-crrob2 phg1-phg2 yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crrob1+crrob2;


/* Assault GSSHG */

proc reg;
Title "Granger, Assault, GSSHG, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model gsshg = crass1-crass2 gsshg1-gsshg2 yr82-yr96
	
 ;
crime:test crass1+crass2;


	/* Granger Tests, Assault, Phg */

proc reg;
Title "Granger, Assault, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model phg = crass1-crass2 phg1-phg2 yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crass1+crass2;


/* Burglary GSSHG */

proc reg;
Title "Granger, Burglary, GSSHG, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model gsshg = crbur1-crbur2 gsshg1-gsshg2 yr82-yr96	
 ;
crime:test crbur1+crbur2;



	/* Granger Tests, Burglary, Phg */

proc reg;
Title "Granger, Burglary, Phg, no st dum, weighted, with arrests, year dummies ";
Title2 "No control variables";
weight pop;

model phg = crbur1-crbur2 phg1-phg2 yr82-yr96
 ;
yrdums:test yr82,yr83,yr84,yr85,yr86,yr87,yr88,yr89,yr90,yr91,
			yr92,yr93,yr94,yr95,yr96;
crime:test crbur1+crbur2;



run;
