/****************************************************/
/* Guns and Crime                                   */
/* Hausman-Wu tests OLS, 2sls,all crime categories  */
/* Short run, first differences, with arrests       */
/* Produces Table 7                                 */
/****************************************************/

/* insert library reference here */
libname a "/home/cemood/myfiles/Data";
options nocenter nolabel;

/* get data from guns.sas7bdat */
data temp;set a.guns;

/* drop DC */
if state ne 9;


/* Define pgs here */


Pgs=pctgsuic;


/* fix prison population here             */

if pradj=. then pradj=0;
prison=prcye+pradj;
prison=(prison+lag(prison))/2;
prison=prison/pop;

/* make variables here */

ptot=p0099;
p1517=p1517/ptot;
p1824=p1824/ptot;
p2534=p2534/ptot;
p3544=p3544/ptot;
p4554=p4554/ptot;
p5564=p5564/ptot;

rpcpi=rpcpi/1000;
rpcui=rpcui/1000;
rpcim=rpcim/1000;
rpcrpo=rpcrpo/1000;

trend=year-76;


/***********************/
/* define arrests here */
/***********************/
crmaj=crmur+crrap+crrob+crass+crbur;
aoass=aoaga;
aomaj=aomur*(crmur/crmaj)+aorap*(crrap/crmaj)
       +aorob*(crrob/crmaj)+aoass*(crass/crmaj)
       +aobur*(crbur/crmaj);
crvio=crmur+crrap+crrob+crass;

crmur=crmur/pop*1000;
crrap=crrap/pop*1000;
crrob=crrob/pop*1000;
crass=crass/pop*1000;
crbur=crbur/pop*1000;
crlar=crlar/pop*1000;
crmv=crmv/pop*1000;
crmaj=crmaj/pop*1000;
crvio=crvio/pop*1000;

military=empmil;


array yr yr77-yr98;
do over yr;
if year-76=_i_ then yr=1;else yr=0;
end;

array st st1-st51;
do over st;
if state=_i_ then st=1;else st=0;
end;


/* Take per capita gun mags here */

Array zz gunsamm amhgs amhms amrmms;
do over zz;
zz=zz/pop;
end;

/* define guns here */
hg=gsshgra*100;
gun=gssra*100;


/* take logs here */
Array x crmaj crmur crrap crrob crass crbur;
	do over x;
	x=log(x);
	end;

/* take first differences here */

Array xx crmaj crmur crrap crrob crass crbur
	aomaj aomur aorap aorob aoass aobur
	gun hg phg pgun pgs prison  
	gunsamm amhgs amhms amrmms
    metpct ampct military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo 
	yr82-yr98; 
do over xx;
xx=dif(xx);
end;

dpop=dif(pop);

/* take lags here  */

Array z crmaj crmur crrap crrob crass crbur
	aomaj aomur aorap aorob aoass aobur
	gun hg phg pgun pgs prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo ;
	;
Array z1 crmaj1 crmur1 crrap1 crrob1 crass1 crbur1
	aomaj1 aomur1 aorap1 aorob1 aoass1 aobur1
	gun1 hg1 phg1 pgun1 pgs1 pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1 ;
	
Array z2 crmaj2 crmur2 crrap2 crrob2 crass2 crbur2
	aomaj2 aomur2 aorap2 aorob2 aoass2 aobur2
	gun2 hg2 phg2 pgun2 pgs2 pr2  
	ga2 amhg2 amh2 amrm2
    metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2 ;

do over z;
z1=lag(z);
z2=lag2(z);


end;

 


/* hg all crimes */

/* crmaj */

proc reg noprint;
Title "Reduced Form, hg, major crime, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model hg crmaj=
	prison aomaj
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crmaj1 aomaj1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crmaj2 aomaj2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=hghat crmajhat;

proc reg;
title "Hausman-Wu Test hg";
weight pop;
model crmaj= hg hghat aomaj crmaj1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, hg, major crime";
weight pop;
endogenous crmaj hg ;
instruments
	prison aomaj
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crmaj1 aomaj1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crmaj2 aomaj2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crmaj= hg prison aomaj  
	crmaj1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, hg, major crime";
model crmaj= hg prison aomaj  
	crmaj1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

/* crmur */

proc reg noprint;
Title "Reduced Form, hg, Murder, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model hg crmur=
	prison aomur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crmur1 aomur1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crmur2 aomur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=hghat crmurhat;

proc reg;
title "Hausman-Wu Test hg";
weight pop;
model crmur= hg hghat aomur crmur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, hg, Murder";
weight pop;
endogenous crmur hg ;
instruments
	prison aomur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crmur1 aomur1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crmur2 aomur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crmur= hg prison aomur  
	crmur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, hg, Murder";
model crmur= hg prison aomur  
	crmur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;


/* crrap */

proc reg noprint;
Title "Reduced Form, hg, crrap, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model hg crrap=
	prison aorap
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crrap1 aorap1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crrap2 aorap2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=hghat crraphat;

proc reg;
title "Hausman-Wu Test hg";
weight pop;
model crrap= hg hghat aorap crrap1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, hg, crrap";
weight pop;
endogenous crrap hg ;
instruments
	prison aorap
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crrap1 aorap1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crrap2 aorap2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crrap= hg prison  aorap 
	crrap1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, hg, crrap";
model crrap= hg prison aorap  
	crrap1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
/* crrob */

proc reg noprint;
Title "Reduced Form, hg, crrob, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model hg crrob=
	prison aorob
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crrob1 aorob1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crrob2 aorob2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=hghat crrobhat;

proc reg;
title "Hausman-Wu Test hg";
weight pop;
model crrob= hg hghat aorob crrob1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, hg, crrob";
weight pop;
endogenous crrob hg ;
instruments
	prison aorob
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crrob1 aorob1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crrob2 aorob2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crrob= hg prison aorob
	crrob1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, hg, crrob";
model crrob= hg prison aorob  
	crrob1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

/* crass */

proc reg noprint;
Title "Reduced Form, hg, crass, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model hg crass=
	prison aoass
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crass1 aoass1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crass2 aoass2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=hghat crasshat;

proc reg;
title "Hausman-Wu Test hg";
weight pop;
model crass= hg hghat aoass crass1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, hg, crass";
weight pop;
endogenous crass hg ;
instruments
	prison aoass
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crass1 aoass1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crass2 aoass2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crass= hg prison  aoass 
	crass1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, hg, crass";
model crass= hg prison aoass  
	crass1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

/* crbur */

proc reg noprint;
Title "Reduced Form, hg, crbur, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model hg crbur=
	prison aobur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crbur1 aobur1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crbur2 aobur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=hghat crburhat;

proc reg;
title "Hausman-Wu Test hg";
weight pop;
model crbur= hg hghat aobur crbur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, hg, crbur";
weight pop;
endogenous crbur hg ;
instruments
	prison aobur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	hg1 crbur1 aobur1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	hg2 crbur2 aobur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crbur= hg prison aobur  
	crbur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, hg, crbur";
model crbur= hg prison aobur  
	crbur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

run;

/* phg all crimes */

/* crmaj */

proc reg noprint;
Title "Reduced Form, phg, major crime, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model phg crmaj=
	prison aomaj
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmaj1 aomaj1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crmaj2 aomaj2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crmajhat;

proc reg;
title "Hausman-Wu Test phg";
weight pop;
model crmaj= phg phghat aomaj crmaj1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, phg, major crime";
weight pop;
endogenous crmaj phg ;
instruments
	prison aomaj
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmaj1 aomaj1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crmaj2 aomaj2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crmaj= phg prison aomaj  
	crmaj1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, phg, major crime";
model crmaj= phg prison aomaj  
	crmaj1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

/* crmur */

proc reg noprint;
Title "Reduced Form, phg, Murder, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model phg crmur=
	prison aomur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmur1 aomur1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crmur2 aomur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crmurhat;

proc reg;
title "Hausman-Wu Test phg";
weight pop;
model crmur= phg phghat aomur crmur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, phg, Murder";
weight pop;
endogenous crmur phg ;
instruments
	prison aomur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmur1 aomur1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crmur2 aomur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crmur= phg prison aomur  
	crmur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, phg, Murder";
model crmur= phg prison aomur  
	crmur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;


/* crrap */

proc reg noprint;
Title "Reduced Form, phg, crrap, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model phg crrap=
	prison aorap
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrap1 aorap1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crrap2 aorap2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crraphat;

proc reg;
title "Hausman-Wu Test phg";
weight pop;
model crrap= phg phghat aorap crrap1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, phg, crrap";
weight pop;
endogenous crrap phg ;
instruments
	prison aorap
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrap1 aorap1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crrap2 aorap2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crrap= phg prison aorap 
	crrap1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, phg, crrap";
model crrap= phg prison aorap  
	crrap1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
/* crrob */

proc reg noprint;
Title "Reduced Form, phg, crrob, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model phg crrob=
	prison aorob
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrob1 aorob1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crrob2 aorob2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crrobhat;

proc reg;
title "Hausman-Wu Test phg";
weight pop;
model crrob= phg phghat aorob crrob1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, phg, crrob";
weight pop;
endogenous crrob phg ;
instruments
	prison aorob
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrob1 aorob1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crrob2 aorob2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crrob= phg prison  aorob 
	crrob1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, phg, crrob";
model crrob= phg prison aorob  
	crrob1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

/* crass */

proc reg noprint;
Title "Reduced Form, phg, crass, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model phg crass=
	prison aoass
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crass1 aoass1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crass2 aoass2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crasshat;

proc reg;
title "Hausman-Wu Test phg";
weight pop;
model crass= phg phghat aoass crass1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, phg, crass";
weight pop;
endogenous crass phg ;
instruments
	prison aoass
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crass1 aoass1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crass2 aoass2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crass= phg prison  aoass 
	crass1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, phg, crass";
model crass= phg prison aoass  
	crass1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;

/* crbur */

proc reg noprint;
Title "Reduced Form, phg, crbur, Unweighted, yr dums";
Title2 "No state dummies";
*weight pop;

model phg crbur=
	prison aobur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crbur1 aobur1
	pr1 
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crbur2 aobur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crburhat;

proc reg;
title "Hausman-Wu Test phg";
weight pop;
model crbur= phg phghat aobur crbur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;
proc syslin 2sls;
Title "2SLS, phg, crbur";
weight pop;
endogenous crbur phg ;
instruments
	prison aobur
	  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crbur1 aobur1
	pr1
	  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	phg2 crbur2 aobur2
	pr2 
	  
	ga2 amhg2 amh2 amrm2
	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	yr85-yr97
	st1-st51
 ;
model crbur= phg prison  aobur 
	crbur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	/overid
	;

Proc reg;
Title "OLS, phg, crbur";
model crbur= phg prison aobur  
	crbur1 
	metpct ampct dpop
	rpcpi rpcim rpcui rpcrpo
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	;


run;
