/****************************************************/
/* Guns and Crime                                   */
/* Hausman-Wu tests OLS, 2sls, Gun Eqs All crimes   */
/* Short run, first differences                     */
/* Not logged                                       */
/* Produces Table 8                                 */
/****************************************************/

/* insert library reference here */
libname a "/home/cemood/myfiles/Data";
options nocenter nolabel pagesize=1000;

/* get data from guns.sas7bdat */
data temp;set a.guns;

/* drop DC */
if state ne 9;

/* Define pgs here */
Pgs=pctgsuic;

/* Define guns here */
gsshg=gsshgra*100;
gss=gssra*100;


/* fix prison population here             */
/* note that prison is stock at year end  */
if pradj=. then pradj=0;
prison=prcye+pradj;
prison=(prison+lag(prison))/2;
prison=prison/pop;

/* make variables here */

ptot=p0099;
p1517=p1517/ptot;
p1824=p1824/ptot;
p2534=p2534/ptot;
p3544=p3544/ptot;
p4554=p4554/ptot;
p5564=p5564/ptot;

rpcpi=rpcpi/1000;
rpcui=rpcui/1000;
rpcim=rpcim/1000;
rpcrpo=rpcrpo/1000;
employ=employ/1000000;

trend=year-76;


crmaj=crmur+crrap+crrob+crass+crbur;
crvio=crmur+crrap+crrob+crass;
crmur=crmur/pop*1000;
crrap=crrap/pop*1000;
crrob=crrob/pop*1000;
crass=crass/pop*1000;
crbur=crbur/pop*1000;
crlar=crlar/pop*1000;
crmv=crmv/pop*1000;
crmaj=crmaj/pop*1000;
crvio=crvio/pop*1000;

military=empmil;

/*******************************/
/* Define arrests here         */
/*******************************/
aoass=aoaga;
aomaj=aomur*(crmur/crmaj)+aorap*(crrap/crmaj)
       +aorob*(crrob/crmaj)+aoass*(crass/crmaj)

       +aobur*(crbur/crmaj);


array yr yr77-yr98;
do over yr;
if year-76=_i_ then yr=1;else yr=0;
end;

array st st1-st51;
do over st;
if state=_i_ then st=1;else st=0;
end;


/* Take per capita gun mags here */

Array zz gunsamm amhgs amhms amrmms;
do over zz;
zz=zz/pop;
end;


/* dont take logs */

	
/* take first differences here */

Array xx  crmaj crmur crrap crrob crass crbur
		aomaj aomur aorap aorob aoass aobur 
		gss gsshg phg pgun pgs prison 
		gunsamm amhgs amhms amrmms
    		metpct ampct military employ unrate
		p1517 p1824 p2534 p3544 p4554 p5564
		rpcpi rpcim rpcui rpcrpo
		;
do over xx;
	xx=dif(xx);
end;

dpop=dif(pop);

/* take lags here  */

Array z crmaj crmur crrap crrob crass crbur
		aomaj aomur aorap aorob aoass aobur  
	gss gsshg phg pgun pgs 
	prison 
	gunsamm amhgs amhms amrmms
    	metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	;
Array z1 crmaj1 crmur1 crrap1 crrob1 crass1 crbur1
		 aomaj1 aomur1 aorap1 aorob1 aoass1 aobur1 
	gss1 gsshg1 phg1 pgun1 pgs1
	pr1  
	ga1 amhg1 amh1 amrm1
    	metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	;
Array z2 crmaj2 crmur2 crrap2 crrob2 crass2 crbur2
		aomaj2 aomur2 aorap2 aorob2 aoass2 aobur2 
		gss2 gsshg2 phg2 pgun2 pgs2 
		pr2 
	ga2 amhg2 amh2 amrm2
    	metpct2 ampct2 dpop2 mil2 employ2 unrate2
	p15172 p18242 p25342 p35442 p45542 p55642
	rpcpi2 rpcim2 rpcui2 rpcrpo2
	;
	

do over z;
z1=lag(z);
z2=lag2(z);


end;


/*  Major Crime */

proc reg noprint;
Title "Reduced Form, gsshg, Major Crime, Unweighted, yr dums";
*weight pop;

model gsshg crmaj=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crmaj1
	pr1 
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	st1-st51
 ;
Output out=crime p=gsshghat crmajhat;

proc reg ;
title "Hausman-Wu Test gsshg";
weight pop;
model gsshg= crmaj crmajhat gsshg1
	gunsamm  amrmms
     
	;
proc syslin 2sls;
Title "2SLS, gsshg, Major Crime";
weight pop;
endogenous crmaj gsshg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crmaj1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model gsshg= crmaj gsshg1
	gunsamm  amrmms
     
	/overid
	;



	proc reg;
	title "OLS, gsshg, Major Crime";
	weight pop;
	model gsshg= crmaj gsshg1
	gunsamm  amrmms
     
	 ;



/* PHG Major Crime */

proc reg noprint;
Title "Reduced Form, PHG, Major Crime, Unweighted, yr dums";
*weight pop;

model phg crmaj=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmaj1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crmajhat;

proc reg ;
title "Hausman-Wu Test PHG";
weight pop;
model phg= crmaj crmajhat phg1 
	gunsamm  amrmms
    
	 ;
	
proc syslin 2sls;
Title "2SLS, PHG, Major Crime";
weight pop;
endogenous crmaj phg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmaj1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model phg= crmaj phg1 
	gunsamm amrmms
     
	/overid
	;


	proc reg;
	title "OLS, PHG, Major Crime";
	weight pop;
	model phg= crmaj phg1 
	gunsamm amrmms
     
	 ;

/*  Murder */

proc reg noprint;
Title "Reduced Form, gsshg, murder, Unweighted, yr dums";
*weight pop;

model gsshg crmur=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crmur1
	pr1 
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641

	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	st1-st51
 ;
Output out=crime p=gsshghat crmurhat;

proc reg ;
title "Hausman-Wu Test gsshg Murder";
weight pop;
model gsshg= crmur crmurhat gsshg1
	gunsamm  amrmms
     
	;
proc syslin 2sls;
Title "2SLS, gsshg, murder";
weight pop;
endogenous crmur gsshg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crmur1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model gsshg= crmur gsshg1
	gunsamm  amrmms
     
	/overid
	;



	proc reg;
	title "OLS, gsshg, murder";
	weight pop;
	model gsshg= crmur gsshg1
	gunsamm  amrmms
     
	 ;



/* PHG murder */

proc reg noprint;
Title "Reduced Form, PHG, murder, Unweighted, yr dums";
*weight pop;

model phg crmur=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmur1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crmurhat;

proc reg ;
title "Hausman-Wu Test PHG";
weight pop;
model phg= crmur crmurhat phg1 
	gunsamm  amrmms
    
	 ;
	
proc syslin 2sls;
Title "2SLS, PHG, murder";
weight pop;
endogenous crmur phg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crmur1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model phg= crmur phg1 
	gunsamm amrmms
     
	/overid
	;


	proc reg;
	title "OLS, PHG, murder";
	weight pop;
	model phg= crmur phg1 
	gunsamm amrmms
     ;

/*  rape */

proc reg noprint;
Title "Reduced Form, gsshg, rape, Unweighted, yr dums";
*weight pop;

model gsshg crrap=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crrap1
	pr1 
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	st1-st51
 ;
Output out=crime p=gsshghat crraphat;

proc reg ;
title "Hausman-Wu Test gsshg rape";
weight pop;
model gsshg= crrap crraphat gsshg1
	gunsamm  amrmms
     
	;
proc syslin 2sls;
Title "2SLS, gsshg, rape";
weight pop;
endogenous crrap gsshg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crrap1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model gsshg= crrap gsshg1
	gunsamm  amrmms
     
	/overid
	;



	proc reg;
	title "OLS, gsshg, rape";
	weight pop;
	model gsshg= crrap gsshg1
	gunsamm  amrmms
     
	 ;



/* PHG rape */

proc reg noprint;
Title "Reduced Form, PHG, rape, Unweighted, yr dums";
*weight pop;

model phg crrap=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrap1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crraphat;

proc reg ;
title "Hausman-Wu Test PHG";
weight pop;
model phg= crrap crraphat phg1 
	gunsamm  amrmms
    
	 ;
	
proc syslin 2sls;
Title "2SLS, PHG, rape";
weight pop;
endogenous crrap phg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrap1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model phg= crrap phg1 
	gunsamm amrmms
     
	/overid
	;


	proc reg;
	title "OLS, PHG, rape";
	weight pop;
	model phg= crrap phg1 
	gunsamm amrmms
     ;

	/*  robbery */

proc reg noprint;
Title "Reduced Form, gsshg, robbery, Unweighted, yr dums";
*weight pop;

model gsshg crrob=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crrob1
	pr1 
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	st1-st51
 ;
Output out=crime p=gsshghat crrobhat;

proc reg ;
title "Hausman-Wu Test gsshg robbery";
weight pop;
model gsshg= crrob crrobhat gsshg1
	gunsamm  amrmms
     
	;
proc syslin 2sls;
Title "2SLS, gsshg, robbery";
weight pop;
endogenous crrob gsshg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crrob1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model gsshg= crrob gsshg1
	gunsamm  amrmms
     
	/overid
	;



	proc reg;
	title "OLS, gsshg, robbery";
	weight pop;
	model gsshg= crrob gsshg1
	gunsamm  amrmms
     
	 ;



/* PHG robbery */

proc reg noprint;
Title "Reduced Form, PHG, robbery, Unweighted, yr dums";
*weight pop;

model phg crrob=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrob1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crrobhat;

proc reg ;
title "Hausman-Wu Test PHG";
weight pop;
model phg= crrob crrobhat phg1 
	gunsamm  amrmms
    
	 ;
	
proc syslin 2sls;
Title "2SLS, PHG, robbery";
weight pop;
endogenous crrob phg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crrob1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model phg= crrob phg1 

	gunsamm amrmms
     
	/overid
	;


	proc reg;
	title "OLS, PHG, robbery";
	weight pop;
	model phg= crrob phg1 
	gunsamm amrmms
     ;

	/*  assault */

proc reg noprint;
Title "Reduced Form, gsshg, assault, Unweighted, yr dums";
*weight pop;

model gsshg crass=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crass1
	pr1 
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	st1-st51
 ;
Output out=crime p=gsshghat crasshat;

proc reg ;
title "Hausman-Wu Test gsshg assault";
weight pop;
model gsshg= crass crasshat gsshg1
	gunsamm  amrmms
     
	;
proc syslin 2sls;
Title "2SLS, gsshg, assault";
weight pop;
endogenous crass gsshg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crass1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model gsshg= crass gsshg1
	gunsamm  amrmms
     
	/overid
	;



	proc reg;
	title "OLS, gsshg, assault";
	weight pop;
	model gsshg= crass gsshg1
	gunsamm  amrmms
     
	 ;



/* PHG assault */

proc reg noprint;
Title "Reduced Form, PHG, assault, Unweighted, yr dums";
*weight pop;

model phg crass=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crass1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crasshat;

proc reg ;
title "Hausman-Wu Test PHG";
weight pop;
model phg= crass crasshat phg1 
	gunsamm  amrmms
    
	 ;
	
proc syslin 2sls;
Title "2SLS, PHG, assault";
weight pop;
endogenous crass phg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crass1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model phg= crass phg1 
	gunsamm amrmms
     
	/overid
	;


	proc reg;

	title "OLS, PHG, assault";
	weight pop;
	model phg= crass phg1 
	gunsamm amrmms
     ;

	/*  burglary */

proc reg noprint;
Title "Reduced Form, gsshg, burglary, Unweighted, yr dums";
*weight pop;

model gsshg crbur=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crbur1
	pr1 
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	yr85-yr97
	st1-st51
 ;
Output out=crime p=gsshghat crburhat;

proc reg ;
title "Hausman-Wu Test gsshg burglary";
weight pop;
model gsshg= crbur crburhat gsshg1
	gunsamm  amrmms
     
	;
proc syslin 2sls;

Title "2SLS, gsshg, burglary";
weight pop;
endogenous crbur gsshg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	gsshg1 crbur1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model gsshg= crbur gsshg1
	gunsamm  amrmms
     
	/overid
	;



	proc reg;
	title "OLS, gsshg, burglary";
	weight pop;
	model gsshg= crbur gsshg1
	gunsamm  amrmms
     
	 ;



/* PHG burglary */

proc reg noprint;
Title "Reduced Form, PHG, burglary, Unweighted, yr dums";
*weight pop;

model phg crbur=
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crbur1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
Output out=crime p=phghat crburhat;

proc reg ;
title "Hausman-Wu Test PHG";
weight pop;
model phg= crbur crburhat phg1 
	gunsamm  amrmms
    
	 ;
	
proc syslin 2sls;
Title "2SLS, PHG, burglary";
weight pop;
endogenous crbur phg ;
instruments
	prison  
	gunsamm amhgs amhms amrmms
    metpct ampct dpop military employ unrate
	p1517 p1824 p2534 p3544 p4554 p5564
	rpcpi rpcim rpcui rpcrpo
	phg1 crbur1
	pr1  
	ga1 amhg1 amh1 amrm1
    metpct1 ampct1 dpop1 mil1 employ1 unrate1
	p15171 p18241 p25341 p35441 p45541 p55641
	rpcpi1 rpcim1 rpcui1 rpcrpo1
	
	yr85-yr97
	st1-st51
 ;
model phg= crbur phg1 
	gunsamm amrmms
     
	/overid
	;


	proc reg;
	title "OLS, PHG, burglary";
	weight pop;
	model phg= crbur phg1 
	gunsamm amrmms
     ;



run;
